@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/aquasecurity/tfsec/internal/app/tfsec/custom"
+	"github.com/aquasecurity/tfsec/internal/pkg/custom"
 	"github.com/spf13/cobra"
 )
 
