@@ -4,13 +4,11 @@ import (
 	"fmt"
 	"os"
 	"sort"
+	"strings"
 
-	"github.com/aquasecurity/tfsec/pkg/rule"
-
+	_ "github.com/aquasecurity/tfsec/internal/pkg/rules"
+	"github.com/aquasecurity/tfsec/internal/pkg/scanner"
 	"github.com/spf13/cobra"
-
-	_ "github.com/aquasecurity/tfsec/internal/app/tfsec/rules"
-	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
 )
 
 var (
@@ -20,7 +18,7 @@ var (
 
 type FileContent struct {
 	Provider string
-	Checks   []rule.Rule
+	Checks   []templateObject
 }
 
 func init() {
@@ -39,13 +37,8 @@ var rootCmd = &cobra.Command{
 	Use:   "tfsec-docs",
 	Short: "tfsec-docs generates documentation for the checks in tfsec",
 	Long:  `tfsec-docs generates the content for the root README and also can generate the missing base pages for the wiki`,
-	RunE: func(cmd *cobra.Command, args []string) error {
-
+	RunE: func(_ *cobra.Command, _ []string) error {
 		fileContents := getSortedFileContents()
-		if err := generateExtensionCodeFile(fileContents); err != nil {
-			return err
-		}
-
 		return generateWebPages(fileContents)
 	},
 }
@@ -53,11 +46,24 @@ var rootCmd = &cobra.Command{
 func getSortedFileContents() []*FileContent {
 	rules := scanner.GetRegisteredRules()
 
-	checkMap := make(map[string][]rule.Rule)
+	checkMap := make(map[string][]templateObject)
 
 	for _, r := range rules {
-		provider := string(r.Provider)
-		checkMap[provider] = append(checkMap[provider], r)
+		provider := string(r.Base.Rule().Provider)
+		checkMap[provider] = append(checkMap[provider], templateObject{
+			ID:          r.ID(),
+			ShortCode:   r.Base.Rule().ShortCode,
+			Severity:    strings.ToLower(string(r.Base.Rule().Severity)),
+			Service:     r.Base.Rule().Service,
+			Provider:    string(r.Base.Rule().Provider),
+			Summary:     r.Base.Rule().Summary,
+			Explanation: r.Base.Rule().Explanation,
+			Impact:      r.Base.Rule().Impact,
+			Resolution:  r.Base.Rule().Resolution,
+			BadExample:  r.Base.Rule().Terraform.BadExamples[0],
+			GoodExample: r.Base.Rule().Terraform.GoodExamples[0],
+			Links:       append(r.Base.Rule().Terraform.Links, r.Base.Rule().Links...),
+		})
 	}
 
 	var fileContents []*FileContent
@@ -72,8 +78,8 @@ func getSortedFileContents() []*FileContent {
 	return fileContents
 }
 
-func sortChecks(checks []rule.Rule) {
+func sortChecks(checks []templateObject) {
 	sort.Slice(checks, func(i, j int) bool {
-		return checks[i].ID() < checks[j].ID()
+		return checks[i].ID < checks[j].ID
 	})
 }
