@@ -23,28 +23,26 @@ func adaptBrokers(modules block.Modules) []mq.Broker {
 }
 
 func adaptBroker(resource *block.Block) mq.Broker {
-	publicAccessAttr := resource.GetAttribute("publicly_accessible")
-	publicAccessVal := publicAccessAttr.AsBoolValueOrDefault(false, resource)
 
-	auditVal := types.Bool(false, *resource.GetMetadata())
-	generalVal := types.Bool(false, *resource.GetMetadata())
-
-	if resource.HasChild("logs") {
-		logsBlock := resource.GetBlock("logs")
-
-		auditAttr := logsBlock.GetAttribute("audit")
-		auditVal = auditAttr.AsBoolValueOrDefault(false, logsBlock)
-
-		generalAttr := logsBlock.GetAttribute("general")
-		generalVal = generalAttr.AsBoolValueOrDefault(false, logsBlock)
-	}
-
-	return mq.Broker{
-		Metadata:     *resource.GetMetadata(),
-		PublicAccess: publicAccessVal,
+	broker := mq.Broker{
+		Metadata:     resource.Metadata(),
+		PublicAccess: types.BoolDefault(false, resource.Metadata()),
 		Logging: mq.Logging{
-			General: generalVal,
-			Audit:   auditVal,
+			Metadata: resource.Metadata(),
+			General:  types.BoolDefault(false, resource.Metadata()),
+			Audit:    types.BoolDefault(false, resource.Metadata()),
 		},
 	}
+
+	publicAccessAttr := resource.GetAttribute("publicly_accessible")
+	broker.PublicAccess = publicAccessAttr.AsBoolValueOrDefault(false, resource)
+	if logsBlock := resource.GetBlock("logs"); logsBlock.IsNotNil() {
+		broker.Logging.Metadata = logsBlock.Metadata()
+		auditAttr := logsBlock.GetAttribute("audit")
+		broker.Logging.Audit = auditAttr.AsBoolValueOrDefault(false, logsBlock)
+		generalAttr := logsBlock.GetAttribute("general")
+		broker.Logging.General = generalAttr.AsBoolValueOrDefault(false, logsBlock)
+	}
+
+	return broker
 }
