@@ -38,6 +38,6 @@ func adaptInstance(resource *block.Block) compute.Instance {
 
 	return compute.Instance{
 		Metadata: resource.Metadata(),
-		UserData: types.String(string(encoded), *resource.GetMetadata()),
+		UserData: types.String(string(encoded), resource.Metadata()),
 	}
 }
